==> unity_7.2.6+14.04.20160408.orig.tar.gz: tests/test_bamf_application.cpp <==
/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * version 3 along with this program. If not, see
 * <http://www.gnu.org/licenses/>
 *
 * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
 */

#include <glib.h>
#include <gmock/gmock.h>

#include "BamfApplicationManager.h"
#include "bamf-mock-application.h"
#include "bamf-mock-window.h"
#include "mock-application.h"
#include "test_standalone_wm.h"

#include <UnityCore/GLibWrapper.h>

namespace {

unity::StandaloneWindow::Ptr AddFakeWindowToWM(Window xid, bool mapped)
{
  auto fake_window = std::make_shared<unity::StandaloneWindow>(xid);
  fake_window->mapped = mapped;

  auto wm = unity::testwrapper::StandaloneWM::Get();
  wm->AddStandaloneWindow(fake_window);

  return fake_window;
}

struct TestBamfApplication : public testing::Test
{
  TestBamfApplication()
    : bamf_mock_application_(bamf_mock_application_new())
    , application_(mock_manager_, unity::glib::object_cast<BamfApplication>(bamf_mock_application_))
  {}

  unity::testwrapper::StandaloneWM WM;
  testmocks::MockApplicationManager::Nice mock_manager_;
  unity::glib::Object<BamfMockApplication> bamf_mock_application_;
  unity::bamf::Application application_;
};

TEST_F(TestBamfApplication, GetWindows)
{
  GList* children = nullptr;
  for (int i = 0; i<5; ++i)
  {
  	BamfMockWindow* window = bamf_mock_window_new();
  	bamf_mock_window_set_xid(window, i);
    children = g_list_append(children, window);
  }
  bamf_mock_application_set_children(bamf_mock_application_, children);

  AddFakeWindowToWM(0, true);
  AddFakeWindowToWM(1, true);
  AddFakeWindowToWM(2, false);
  AddFakeWindowToWM(3, true);
  AddFakeWindowToWM(4, false);

  auto windows = application_.GetWindows();
  ASSERT_EQ(windows.size(), 5);

  g_list_free_full(children, g_object_unref);
}

}

==> unity_7.4.5+16.04.20190312.orig.tar.gz: tests/test_bamf_application.cpp <==
/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * version 3 along with this program. If not, see
 * <http://www.gnu.org/licenses/>
 *
 * Authored by: Andrea Azzarone <andrea.azzarone@canonical.com>
 */

#include <glib.h>
#include <gmock/gmock.h>

#include "BamfApplicationManager.h"
#include "bamf-mock-application.h"
#include "bamf-mock-window.h"
#include "mock-application.h"
#include "test_standalone_wm.h"

#include <UnityCore/GLibWrapper.h>

namespace unity
{

bool operator==(ApplicationPtr const& lhs, ApplicationPtr const& rhs)
{
  return (lhs.get() == rhs.get() || (lhs && rhs && *lhs == *rhs));
}

bool operator!=(ApplicationPtr const& lhs, ApplicationPtr const& rhs)
{
  return !(lhs == rhs);
}

bool operator==(ApplicationWindowPtr const& lhs, ApplicationWindowPtr const& rhs)
{
  return (lhs.get() == rhs.get() || (lhs && rhs && *lhs == *rhs));
}

bool operator!=(ApplicationWindowPtr const& lhs, ApplicationWindowPtr const& rhs)
{
  return !(lhs == rhs);
}

}

namespace {

unity::StandaloneWindow::Ptr AddFakeWindowToWM(Window xid, bool mapped)
{
  auto fake_window = std::make_shared<unity::StandaloneWindow>(xid);
  fake_window->mapped = mapped;

  auto wm = unity::testwrapper::StandaloneWM::Get();
  wm->AddStandaloneWindow(fake_window);

  return fake_window;
}

struct TestBamfApplication : public testing::Test
{
  TestBamfApplication()
    : bamf_mock_application_(bamf_mock_application_new())
    , application_(mock_manager_, unity::glib::object_cast<BamfApplication>(bamf_mock_application_))
  {}

  unity::testwrapper::StandaloneWM WM;
  testmocks::MockApplicationManager::Nice mock_manager_;
  unity::glib::Object<BamfMockApplication> bamf_mock_application_;
  unity::bamf::Application application_;
};

TEST_F(TestBamfApplication, GetWindows)
{
  ASSERT_EQ(application_.GetWindows().size(), 0u);

  GList* children = nullptr;
  for (int i = 0; i<5; ++i)
  {
  	BamfMockWindow* window = bamf_mock_window_new();
  	bamf_mock_window_set_xid(window, i);
    children = g_list_append(children, window);
  }
  bamf_mock_application_set_children(bamf_mock_application_, children);

  AddFakeWindowToWM(0, true);
  AddFakeWindowToWM(1, true);
  AddFakeWindowToWM(2, false);
  AddFakeWindowToWM(3, true);
  AddFakeWindowToWM(4, false);

  EXPECT_EQ(application_.GetWindows().size(), 5u);

  g_list_free_full(children, g_object_unref);
}

}
